summaryrefslogtreecommitdiffstats
path: root/kjsembed/tools/headers/qpen.h
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/tools/headers/qpen.h')
-rw-r--r--kjsembed/tools/headers/qpen.h38
1 files changed, 19 insertions, 19 deletions
diff --git a/kjsembed/tools/headers/qpen.h b/kjsembed/tools/headers/qpen.h
index 38befc90..7db9325e 100644
--- a/kjsembed/tools/headers/qpen.h
+++ b/kjsembed/tools/headers/qpen.h
@@ -1,7 +1,7 @@
/****************************************************************************
**
**
** Definition of QPen class
**
** Created : 940112
**
@@ -39,35 +39,35 @@
#define QPEN_H
#ifndef QT_H
-#include "qcolor.h"
-#include "qshared.h"
+#include "tqcolor.h"
+#include "tqshared.h"
#endif // QT_H
-class Q_EXPORT QPen: public Qt
+class Q_EXPORT TQPen: public Qt
{
public:
- QPen();
- QPen( PenStyle );
- QPen( const QColor &color, uint width=0, PenStyle style=SolidLine );
- QPen( const QColor &cl, uint w, PenStyle s, PenCapStyle c, PenJoinStyle j);
- QPen( const QPen & );
- ~QPen();
- QPen &operator=( const QPen & );
+ TQPen();
+ TQPen( PenStyle );
+ TQPen( const TQColor &color, uint width=0, PenStyle style=SolidLine );
+ TQPen( const TQColor &cl, uint w, PenStyle s, PenCapStyle c, PenJoinStyle j);
+ TQPen( const TQPen & );
+ ~TQPen();
+ TQPen &operator=( const TQPen & );
PenStyle style() const { return data->style; }
void setStyle( PenStyle );
uint width() const { return data->width; }
void setWidth( uint );
- const QColor &color() const { return data->color; }
- void setColor( const QColor & );
+ const TQColor &color() const { return data->color; }
+ void setColor( const TQColor & );
PenCapStyle capStyle() const;
void setCapStyle( PenCapStyle );
PenJoinStyle joinStyle() const;
void setJoinStyle( PenJoinStyle );
- bool operator==( const QPen &p ) const;
- bool operator!=( const QPen &p ) const
+ bool operator==( const TQPen &p ) const;
+ bool operator!=( const TQPen &p ) const
{ return !(operator==(p)); }
private:
@@ -78,7 +78,7 @@ private:
QPen copy() const;
void detach();
- void init( const QColor &, uint, uint );
+ void init( const TQColor &, uint, uint );
struct QPenData : public QShared { // pen data
PenStyle style;
uint width;
@@ -89,11 +89,11 @@ private:
/*****************************************************************************
- QPen stream functions
+ TQPen stream functions
*****************************************************************************/
#ifndef QT_NO_DATASTREAM
-Q_EXPORT QDataStream &operator<<( QDataStream &, const QPen & );
-Q_EXPORT QDataStream &operator>>( QDataStream &, QPen & );
+Q_EXPORT TQDataStream &operator<<( TQDataStream &, const TQPen & );
+Q_EXPORT TQDataStream &operator>>( TQDataStream &, TQPen & );
#endif
#endif // QPEN_H
@@ -1,7 +1,7 @@
**
**
-** Definition of QPen class
+** Definition of TQPen class
**
** Created : 940112